@@ -15,6 +15,10 @@ class backbone_jax:
         self.func_sum = jnp.sum 
         self.func_sqrt = jnp.sqrt 
         self.var_type = 'jax'
+        if 'device' in kwargs.keys():
+            self.device = kwargs['device']
+        else:
+            self.device = jax.devices('cpu')[0]
         
     def dir_grad(self,mappings,X, D):
         def local_fun(Y):
@@ -65,7 +69,7 @@ class backbone_jax:
 
 
     def array2tensor(self, X_array):
-        return jnp.asarray(X_array)
+        return jax.device_put(jnp.asarray(X_array), device=self.device)
 
     def tensor2array(self, X_tensor):
         return np.array(X_tensor,dtype=np.float64 ,order = 'F')
